@@ -34,8 +34,3 @@ class Payment(object):
         """Process a payment with the configured driver and options."""
         
         return self.adapter.process()
-    
-    def set_field(self, key, value):
-        """Amend the initial configuration."""
-        
-        self.adapter.set_fields({key : value})
